@@ -6,14 +6,14 @@ Apache::Pod - base class for converting Pod files to prettier forms
 
 =head1 VERSION
 
-Version 0.20
+Version 0.22
 
 =cut
 
 use vars qw( $VERSION );
 use strict;
 
-$VERSION = '0.20';
+$VERSION = '0.22';
 
 =head1 SYNOPSIS
 
@@ -77,9 +77,10 @@ Andy Lester <andy at petdance.com>
 
 Adapted from Apache::Perldoc by Rich Bowen.  Thanks also to
 Pete Krawczyk,
-Kjetil Skotheim
-and
+Kjetil Skotheim,
 Kate Yoak
+and
+Chris Eade
 for contributions.
 
 =head1 LICENSE
